%CARTE_SST Ce programme permet de visualiser les cartes mensuelles moyennes de temperature de surface
%
% Date: Avril-Mai 2008
% Auteur: juliette.mignot@locean-ipsl.upmc.fr
% Contexte Ecole d'ete ENVI-STAT 2008

%+
%
% module
% ======
%
% ``carte_SST``
%
% DESCRIPTION
% ===========
%
% ``carte_SST`` visualise les cartes mensuelles moyennes de temprature
% de surface.
%
% ``carte_SST`` lit les fichiers
% ``../DONNEES/lsmask_tropatl_PacandMedblancs.mat``
% et ``../DONNEES/skt.mon.tropatl.mat``.
%
% ``carte_SST`` calcule les moyennes mensuelles de SST dans
% l'Atlantique tropical a partir d'un champ mensuel de 60 ans
% fourni en entree
%
% ``carte_SST`` affiche  l'cran les moyennes mensuelles de SST.
%
% ``carte_SST`` sauve cette image dans ``./carte_SST.ps``.
%
% EXAMPLES
% ========
%
% ::
%
% >> tpacpandreg_startup
% >> carte_SST
%
% SEE ALSO
% ========
%
% tpacpandreg_startup.m_
%
% .. _tpacpandreg_startup.m : tpacpandreg_startup.m.html
%
% initfig.m_
%
% .. _initfig.m : initfig.m.html
%
% whorldmap.m_
%
% .. _whorldmap.m : whorldmap.m.html
%
% colorbartype.m_
%
% .. _colorbartype.m : colorbartype.m.html
%
% contlab.m_
%
% .. _contlab.m : contlab.m.html
%
% TODO
% ====
%
% improve description
%
% KNOWN PROBLEMS
% ==============
% 
% 
% - fplod 2009-08-26T08:46:48Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * ne fonctionne pas sous octave 3.2.2
%     
%     ::
%
%    error: gnuplot (as of v4.2) only supports 3D filled triangular patches
%    error: called from:
%    error:   /usr/local_linux/octave/64/3.2.2//share/octave/3.2.2/m/plot/__go_draw_axes__.m at line 563, column 6
%    error:   /usr/local_linux/octave/64/3.2.2//share/octave/3.2.2/m/plot/__go_draw_figure__.m at line 93, column 3
%    error:   /usr/local_linux/octave/64/3.2.2//share/octave/3.2.2/m/plot/gnuplot_drawnow.m at line 88, column 5
%    error:   /usr/local_linux/octave/64/3.2.2//share/octave/3.2.2/m/plot/print.m at line 696, column 7
%    error:   /.autofs/home/fplod/incas/tpoctave/tpacpandreg_ws/PROGRAMMES/carte_SST.m at line 212, column 1
%    
% EVOLUTIONS
% ==========
%
% $Id$
%
% - fplod 2009-08-26T09:00:11Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%  * titre: nom de chaque mois
%  * remplacement de ``eps`` par ``ps` pour pouvoir imprimer les figures 
%    produites par ``octave``
%    Dans le fichier .eps produit par ``octave`` on pouvait lire 
%    ``!PS-Adobe-2.0 EPSF-2.0``.
%    Aucun message d'erreur n'apparat suite  la demande d'impression 
%    ``zeus$ lpr -o job-sheets='none' carte_SST.ps``, mais aucune feuille ne
%    sort.
%    Pour info dans le fichier .eps produit par matlab, on pouvait lire
%    ``%!PS-Adobe-2.0 EPSF-1.2``. Aucun souci d'impression avec ce fichier !
%    En remplaant ``eps`` par ``ps`, on n'a plus de souci d'impression.
%
%
% - jmignot 2009-08-25
%
%  * suppression d'appel  contlab et colorbartype sous octave
%
% - fplod 2009-08-25T10:40:16Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%  * modif commentaires lie au dernier chgt de Juliette
%
% - jmignot 2009-08-25
%
%  * remplacement de ``colorbar`` par ``colorbartype``
%    parce pas beau ni en matlab ni en octave (dgrad, noir et blanc dans
%    les .jpg)
%  * contraintes sur les limites x et y de axes car matlab et octave ne
%    fixent pas les mme limites par dfaut
%  * utilisation de ``contlab`` pour ++
%
% - fplod 2009-08-17T12:39:51Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add header
%   * rpertoire de donnes relatifs au rpertoire courant
%   * suppression de ``clear all`` prsent dans ``tpacpandreg_startup.m``
%   * contournement pb octave pour ``contourf`` :
%     Dans le fil de discussion [Pkg-octave-devel] Bug#492223: octave3.0: contourf only accepts vector X and Y if same+++,
%     je comprends que j'ai affaire  un bug de octave 3.0 (donc  surveiller
%     pour les prochaines versions) qui ne veut pas faire de contourf si les
%     variables X et Y n'ont pas la mme dimension et c'est le cas ici
%     (lat = 42x1, lon= 70x1 vue avec size).
%     http://lists.alioth.debian.org/pipermail/pkg-octave-devel/2008-July/004672.html
%   * sauvegarde de la figure dans ``./carte_SST.eps``
%
%-

%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%              CHARGEMENT ET PREPARATION DES DONNEES
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

nannees=60;

   repertoire=[ '..' filesep 'DONNEES' filesep ] % a adapter a chaque cas: chemin d acces aux donnees

%Mask
%-----
   file='lsmask_tropatl_PacandMedblancs.mat'
   load([repertoire file]);
% Data
%--------
  repertoire2=[repertoire 'MAT' filesep] % a adapter a chaque cas: chemin d acces aux donnees
  file=['skt.mon.tropatl.mat']
  load([repertoire2 file]); % chargement des donnees
  tab=permute(tab,[2 3 1]); % permutation des dimensions pour organiser le tableau sous la forme [lat lon temps]

% Application du masque
%----------------------
% le masque donne les positions des continents et des oceans
mask3D=repmat(mask,[1 1 size(tab,3)]);
tab(mask3D~=0)=NaN;

%---------------------------------------------------
%  MANIPULATIONS TEMPORELLES: MOYENNES
%---------------------------------------------------
tab=reshape(tab,size(tab,1),size(tab,2),12,nannees); %organisation du tableau sous la forme [lat lon mois annees]

% Construction de moyennes mensuelles
%---------------------------------------
tab_mens=squeeze(mean(tab,4));


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%               TRACE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%parametres geographiques du graphe
  geo=[-100 20 -30 30]; %[lonmin lonmax latmin latmax];
  yti=[-30:10:30]; xti=[-100:30:20]; %labels de latitude et de longitude

		
% Variabilit saisonnire
%-------------------------
%niveaux de couleurs
lev=[0:1:30];%contours a tracer, en unite du champ a dessiner, ici
             %la SST en degC
	     %a adapter eventuellement
clip_lev=[20 30];%definit les limites des couleurs: bleu fonce au
                 %rouge fonce
	     %a adapter eventuellement


ifigure=1;
figure(ifigure);
clf();
initfig;
for iplot=1:12
  subplot(4,3,iplot)
  if (run_octave == 0)
   x=lon;
   y=lat;
  else
   [x,y]=meshgrid(lon,lat);
  end
  z=squeeze(tab_mens(:,:,iplot));
  contourf(x,y,z,lev)
  caxis(clip_lev)
  hold on
  whorldmap

  % limites gographiques et labels de longitude et de latitude
  ylim([geo(3) geo(4)])
  xlim([geo(1) geo(2)])
  set(gca, 'Xtick', xti, 'Ytick', yti);
  if (run_octave == 0)
    [longstr, latstr] = contlab(xti, yti);
    set(gca, 'Xticklabel', longstr, 'Yticklabel', latstr);
  end;
  if iplot>=10
    xlabel('longitude')
  end;
  if iplot==1|iplot==4|iplot==7|iplot==10
    ylabel('latitude')
  end;

  %titre: nom de chaque mois
  cmois = datestr(datenum([2000 iplot 1 00 00 00]), 'mmm');
  title(cmois);
  clear cmois;

end;

%barre de couleur
if (run_octave == 0)
  pos=[.2 .03 .6 .013];
  hpal=jet(100); %carte des couleurs: du bleu au rouge par defaut.
  colorbartype(pos,lev,1,clip_lev,hpal,0)
  title('SST mensuelle moyenne en degC')
else
 colorbar('East') %colorbar par defaut
end;

% sauvegarde de la figure
printer='ps';
print_printer=['-d', printer];
fullfilename=['./', mfilename, '.', printer];
clear printer;
print(print_printer,fullfilename);
clear print_printer;
clear fullfilename;



