%REG_SERIESTEMPORELLES calcule la regression lineaire d'une serie temporelle issue du champ de donnees initial
% (selectionne en un point d'espace particulier) et une composante principale choisie
%
% Date: Avril-Mai 2008
% Auteur: juliette.mignot@locean-ipsl.upmc.fr
% Contexte Ecole d'ete ENVI-STAT 2008
%%

%+
%
% module
% ======
%
% ``reg_seriestemporelles``
%
% DESCRIPTION
% ===========
%
% ``reg_seriestemporelles`` lit les fichiers fichiers
% ``../DONNEES/lsmask_tropatl_PacandMedblancs.mat``,
% ``../DONNEES/skt.mon.tropatl.mat``.
%
% ``reg_seriestemporelles`` lit aussi le fichier
% ``../DONNEES//eof_SSTmens_tropAtl30N-20S.mat``
% produit par eof_NCEP_sais.m_.
%
% ``reg_seriestemporelles`` calcule ++
%
% ``reg_seriestemporelles`` affiche ++
%
% ``reg_seriestemporelles`` sauve cette image dans
% ``./eof_SSTmens_tropAtl30N-20S.mat_reg_seriestemporelles_1.ps``.
%
% EXAMPLES
% ========
%
% ::
%
% >> tpacpandreg_startup
% >> reg_seriestemporelles
%
%
% SEE ALSO
% ========
%
% tpacpandreg_startup.m_
%
% .. _tpacpandreg_startup.m : tpacpandreg_startup.m.html
%
% eof_NCEP_sais.m_
%
% .. _eof_NCEP_sais.m : eof_NCEP_sais.m.html
%
% TODO
% ====
%
% improve description
%
% pourquoi ``return``  la fin
%
% ajout xlabel et ylabel
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% - fplod 2009-08-26T09:49:43Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%  * remplacement de ``eps`` par ``ps` pour pouvoir imprimer les figures 
%    produites par ``octave``
%
% - fplod 2009-08-25T10:40:16Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * modif commentaires lie au renommage
%
% - jmignot 2009-08-25
%
%   * PROGRAMMES/Reg_seriestemporelles.m renomm en
%     PROGRAMMES/reg_seriestemporelles.m pour viter confusion
%     avec RESULTATS/Reg_seriestemporelles.m
%   * chgt de noms de fichiers : ``EOF_ devient ``eof_``
%
% - fplod 2009-08-24T08:46:31Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add header
%   * rpertoire de donnes relatifs au rpertoire courant
%   * suppression de ``clear all`` prsent dans ``tpacpandreg_startup.m``
%   * as octave save default format is ASCII and no default extension
%     while matlab save default format is MAT v5 mat-file (little endian) and
%     default extension is ``.mat``, write more precise save instruction
%   * save the figure
%
%-

%% PARAMETRES DU PROGRAMME
% selection de la composante principale a considerer
ipc=1; %rang de la composante principale que l'on va considerer ici

% les coordonnees du point d'espace auquel on veut comparer cette
% composante principale doit etre choisi plus bas, apres chargement des
% longitudes et latitudes
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%              CHARGEMENT ET PREPARATION DES DONNEES
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

nannees=60;

repertoire=[ '..' filesep 'DONNEES' filesep ]; % a adapter a chaque cas: chemin d acces aux donnees

% Mask
%-----
   file='lsmask_tropatl_PacandMedblancs.mat'
   load([repertoire file]);
% Data
%--------
  repertoire2=[repertoire 'MAT' filesep] % a adapter a chaque cas: chemin d acces aux donnees
  file=['skt.mon.tropatl.mat']
  load([repertoire2 file]); % chargement des donnees
  tab=permute(tab,[2 3 1]); % permutation des dimensions pour organiser le tableau sous la forme [lat lon temps]

% Application du masque
%----------------------
mask3D=repmat(mask,[1 1 size(tab,3)]);
tab(mask3D~=0)=NaN;


%  MANIPULATIONS TEMPORELLES: MOYENNES

% Construction de moyennes mensuelles saisonnieres
%---------------------------------------------------
tab=reshape(tab,size(tab,1),size(tab,2),12,nannees);
tab=squeeze(mean(tab,4));

%Calcul des anomalies
%tab_mean=squeeze(mean(tab,3));
%tab_mean=repmat(tab_mean,[1 1 size(tab,3)]);
%anom=tab-tab_mean;

%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% selection d'un point d'espace
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% le point d'espace est selectionne en reperant son indice i,j dans le
% tableau de longitude et de latitude

%i=find(lon>-96 & lon<-94);
%j=find(lat>19 & lat<21);
i=find(lon>-96 & lon<-94);
j=find(lat>19 & lat<21);
%i=find(lon>-21 & lon<-19);
%j=find(lat>19 & lat<21);
%i=find(lon>4 & lon<6)
%j=find(lat>-11 & lat<-9)

SST=squeeze(tab(j,i,:));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% chargement des composantes principales
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

file=['eof_SSTmens_tropAtl30N-20S.mat']; % nom du fichier sous lequel on avait enregistre le resultat de l'ACP en moyenne annuelle
titledataeof='SST' % je definis ce nom pour pouvoir l'inclure dans le graphique plus bas.
if (run_octave == 0)
 load([repertoire file]);
else
 load('-v7',[repertoire file]);
end
PC=PC(:,ipc);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%               NUAGE DE POINTS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ifigure=1;
figure(ifigure);
plot(SST,PC,'x')
hold on

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%   REGRESSION LINEAIRE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%[b0,b1,s,R,sigb0,sigb1] = linreg(SST,serie);

SSTmean=mean(SST);PCmean=mean(PC);
n=length(SST);


% la fin du programme est a completer (les formules sont dans le cours ou
% dans les livres)

% calcul de b1 et b0, coefficient directeur et ordonnee a l origine de la
% droite de regression


%trace de la droite de regression
%---------------------------------


%Calcul du coefficient de dtermination
%----------------------------------------

%significativite statistique comparaison de la correlation r et de la
%valeur critique rc donnee par la table de student en fonction du nombre de
%degres de liberte ndf
%------------------------------


% significativite statistique de b0 et b1
%--------------------------------------------

% sauvegarde de la figure
printer='ps';
print_printer=['-d', printer];
fullfilename=['.' filesep file '_' mfilename '_'  num2str(ifigure) '.' printer];
print(print_printer,fullfilename);
clear print_printer;
clear fullfilename;
clear printer;
%
clear ifigure;

return
